@@ -7,17 +7,9 @@ def app(environ, start_response):
     start_response(
         '200 OK',
         [('Content-Length', cl), ('Content-Type', 'text/plain')]
-        )
+    )
     return [body]
 
 if __name__ == '__main__':
-    import logging
-    class NullHandler(logging.Handler):
-        def emit(self, record):
-            pass
-    h = NullHandler()
-    logging.getLogger('waitress').addHandler(h)
-    from waitress import serve
-    serve(app, port=61523, _quiet=True)
-    
-    
+    from waitress.tests.support import start_server
+    start_server(app)
