@@ -2,7 +2,7 @@ def chunks(l, n):
     """ Yield successive n-sized chunks from l.
     """
     for i in range(0, len(l), n):
-        yield l[i:i+n]
+        yield l[i:i + n]
 
 def gen(body):
     for chunk in chunks(body, 10):
@@ -16,7 +16,7 @@ def app(environ, start_response):
     start_response(
         '200 OK',
         [('Content-Type', 'text/plain')]
-        )
+    )
     if environ['PATH_INFO'] == '/list':
         return [body]
     if environ['PATH_INFO'] == '/list_lentwo':
@@ -24,12 +24,5 @@ def app(environ, start_response):
     return gen(body)
 
 if __name__ == '__main__':
-    import logging
-    class NullHandler(logging.Handler):
-        def emit(self, record):
-            pass
-    h = NullHandler()
-    logging.getLogger('waitress').addHandler(h)
-    from waitress import serve
-    serve(app, port=61523, _quiet=True, expose_tracebacks=True)
-    
+    from waitress.tests.support import start_server
+    start_server(app, expose_tracebacks=True)
